@@ -31,12 +31,12 @@ read_rpr <- function(col_positions = NaN, widths = NaN, col_names = NaN, filepat
 
     if (is.nan(filepath)) {
         stop("File must be provided as path or object", call. = FALSE)
-    } else if (is.nan(col_positions) || is.nan(widths) || is.nan(col_names)) {
+    } else if (any(is.nan(col_positions) | is.nan(widths) | is.nan(col_names))) {
         stop("Col positions, widths and names must be given", call. = FALSE)
     } else if (length(unique(sapply(list(widths, col_positions, col_names), length))) > 1) {
         stop("The lengths of the vectors of column names, widths, and positions must be the same", call. = FALSE)
-    } else if ((is.nan(cards) & !is.nan(card_read)) || (!is.nan(cards) & is.nan(card_read) & as.numeric(card_read) !=
-        1)) {
+    } else if (any((is.nan(cards) & !is.nan(card_read)) | (!is.nan(cards) & is.nan(card_read) & as.numeric(card_read) !=
+        1))) {
         stop("If reading a multi-card dataset, the number of cards and the card number to read from must be provided.",
             call. = FALSE)
     }
@@ -54,11 +54,24 @@ read_rpr <- function(col_positions = NaN, widths = NaN, col_names = NaN, filepat
         card_read <- as.numeric(card_read)
     }
 
-    if ((cards == 1) || (is.nan(cards) & is.nan(card_read))) {
+    if (any((cards == 1) | (is.nan(cards) & is.nan(card_read)))) {
         return(readr::read_fwf(filepath, readr::fwf_positions(col_positions, end_positions, col_names)))
     } else {
+
+        cards_tib <- readr::read_fwf(filepath, readr::fwf_positions(col_positions, end_positions, col_names))
+        if (any(is.null(dim(cards_tib)) | (nrow(cards_tib) == 0))) {
+            stop("The polling data could not be loaded. It either was not found or was empty.",
+                 call. = FALSE)
+        }
+
         card_v <- rep(FALSE, cards)
         card_v[card_read] <- TRUE
-        return(readr::read_fwf(filepath, readr::fwf_positions(col_positions, end_positions, col_names))[card_v, ])
+        card_v <- rep(card_v, floor(nrow(cards_tib) / cards))
+
+        if (length(card_v) != nrow(cards_tib)) {
+            warning("There appear to be some irregularities in one or more cards. Be sure all data is present")
+        }
+
+        return(cards_tib[card_v, ])
     }
 }
